from django.db import models
from django.utils.translation import gettext_lazy as _

from ..models import RecurrentImport


class BatchImportation(models.Model):
    class STATUS(models.TextChoices):
        RUNNING = "running", _("Running")
        CANCELED = "canceled", _("Canceled")
        SUCCESS = "success", _("Success")
        FAILED = "failed", _("Failed")

    class Meta:
        verbose_name = _("Batch importation")
        verbose_name_plural = _("Batch importations")
        permissions = [("run_batchimportation", "Can run a batch importation")]
        indexes = [
            models.Index(fields=["created_date"]),
            models.Index(fields=["status"]),
            models.Index(fields=["created_date", "recurrentImport"]),
        ]

    created_date = models.DateTimeField(auto_now_add=True)

    recurrentImport = models.ForeignKey(
        RecurrentImport,
        verbose_name=_("Recurrent import"),
        help_text=_("Reference to the recurrent import processing"),
        blank=True,
        null=True,
        on_delete=models.SET_NULL,
        editable=False,
    )

    url_source = models.URLField(
        verbose_name=_("URL (if not recurrent import)"),
        help_text=_("Source URL if no RecurrentImport is associated."),
        max_length=1024,
        blank=True,
        null=True,
        editable=False,
    )

    status = models.CharField(
        _("Status"),
        max_length=20,
        choices=STATUS.choices,
        default=STATUS.RUNNING,
    )

    error_message = models.CharField(
        verbose_name=_("Error message"), max_length=512, blank=True, null=True
    )

    nb_initial = models.PositiveIntegerField(
        verbose_name=_("Number of collected events"), default=0
    )
    nb_imported = models.PositiveIntegerField(
        verbose_name=_("Number of imported events"), default=0
    )
    nb_updated = models.PositiveIntegerField(
        verbose_name=_("Number of updated events"), default=0
    )
    nb_removed = models.PositiveIntegerField(
        verbose_name=_("Number of removed events"), default=0
    )

    celery_id = models.CharField(max_length=128, default="")
